@@ -161,7 +161,7 @@ def _convert_group(nodes: Iterable[Node], parent: Element, font: Optional[Dict[s
         if token in (*commands.MSTYLE_SIZES, *commands.STYLES):
             node = Node(token=token, children=tuple(n for n in nodes))
             _convert_command(node, parent, _font)
-        elif token in commands.CONVERSION_MAP:
+        elif token in commands.CONVERSION_MAP or token in (commands.MOD, commands.PMOD):
             _convert_command(node, parent, _font)
         elif token in commands.LOCAL_FONTS and node.children is not None:
             _convert_group(iter(node.children), parent, commands.LOCAL_FONTS[token])
@@ -225,6 +225,8 @@ def _convert_command(node: Node, parent: Element, font: Optional[Dict[str, Optio
         parent = SubElement(parent, "mpadded", width="0")
     elif command in (commands.TBINOM, commands.HBOX, commands.MBOX, commands.TFRAC):
         parent = SubElement(parent, "mstyle", displaystyle="false", scriptlevel="0")
+    elif command in (commands.MOD, commands.PMOD):
+        SubElement(parent, "mspace", width="1em")
 
     tag, attributes = copy.deepcopy(commands.CONVERSION_MAP[command])
 
@@ -255,8 +257,13 @@ def _convert_command(node: Node, parent: Element, font: Optional[Dict[str, Optio
 
     if command in commands.LIMIT:
         element.text = command[1:]
+    elif command in (commands.MOD, commands.PMOD):
+        element.text = "mod"
+        SubElement(parent, "mspace", width="0.333em")
     elif node.text is not None:
-        if command == commands.HBOX:
+        if command == commands.MIDDLE:
+            element.text = "&#x{};".format(convert_symbol(node.text))
+        elif command == commands.HBOX:
             mtext: Optional[Element] = element
             for text, mode in separate_by_mode(node.text):
                 if mode == Mode.TEXT:
@@ -280,7 +287,7 @@ def _convert_command(node: Node, parent: Element, font: Optional[Dict[str, Optio
 
     if node.children is not None:
         _parent = element
-        if command == commands.LEFT:
+        if command in (commands.LEFT, commands.MOD, commands.PMOD):
             _parent = parent
         if command in commands.MATRICES:
             if command == commands.CASES:
@@ -338,7 +345,7 @@ def _append_prefix_element(node: Node, parent: Element) -> None:
     size = "2.047em"
     if parent.attrib.get("displaystyle") == "false" or node.token == commands.TBINOM:
         size = "1.2em"
-    if node.token == r"\pmatrix":
+    if node.token in (r"\pmatrix", commands.PMOD):
         _convert_and_append_command(r"\lparen", parent)
     elif node.token in (commands.BINOM, commands.DBINOM, commands.TBINOM):
         _convert_and_append_command(r"\lparen", parent, {"minsize": size, "maxsize": size})
@@ -359,7 +366,7 @@ def _append_postfix_element(node: Node, parent: Element) -> None:
     size = "2.047em"
     if parent.attrib.get("displaystyle") == "false" or node.token == commands.TBINOM:
         size = "1.2em"
-    if node.token == r"\pmatrix":
+    if node.token in (r"\pmatrix", commands.PMOD):
         _convert_and_append_command(r"\rparen", parent)
     elif node.token in (commands.BINOM, commands.DBINOM, commands.TBINOM):
         _convert_and_append_command(r"\rparen", parent, {"minsize": size, "maxsize": size})
